==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/GUITestBase/src/tests/common_scenarios/project/GTTestsProject.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_PROJECT_H_
#define _U2_GUI_TEST_PROJECT_H_

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_project {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_project"

GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0038_1)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0045)
GUI_TEST_CLASS_DECLARATION(test_0046)
GUI_TEST_CLASS_DECLARATION(test_0047)
GUI_TEST_CLASS_DECLARATION(test_0048)
GUI_TEST_CLASS_DECLARATION(test_0049)
GUI_TEST_CLASS_DECLARATION(test_0050)
GUI_TEST_CLASS_DECLARATION(test_0051)
GUI_TEST_CLASS_DECLARATION(test_0052)
GUI_TEST_CLASS_DECLARATION(test_0053)
GUI_TEST_CLASS_DECLARATION(test_0054)
GUI_TEST_CLASS_DECLARATION(test_0055)
GUI_TEST_CLASS_DECLARATION(test_0056)
GUI_TEST_CLASS_DECLARATION(test_0057)
GUI_TEST_CLASS_DECLARATION(test_0058)

//applicaation
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0060)
GUI_TEST_CLASS_DECLARATION(test_0061)
GUI_TEST_CLASS_DECLARATION(test_0062)
GUI_TEST_CLASS_DECLARATION(test_0063)

//msa
GUI_TEST_CLASS_DECLARATION(test_0064)
GUI_TEST_CLASS_DECLARATION(test_0065)
GUI_TEST_CLASS_DECLARATION(test_0066)
GUI_TEST_CLASS_DECLARATION(test_0067)

//seq
GUI_TEST_CLASS_DECLARATION(test_0068)
GUI_TEST_CLASS_DECLARATION(test_0069)
GUI_TEST_CLASS_DECLARATION(test_0070)
GUI_TEST_CLASS_DECLARATION(test_0071)

//annotations
GUI_TEST_CLASS_DECLARATION(test_0072)
GUI_TEST_CLASS_DECLARATION(test_0073)
GUI_TEST_CLASS_DECLARATION(test_0074)

#undef GUI_TEST_SUITE
}

} //namespace

#endif

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/project/GTTestsProject.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_PROJECT_H_
#define _U2_GUI_TEST_PROJECT_H_

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_project {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_project"

GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0038_1)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0045)
GUI_TEST_CLASS_DECLARATION(test_0046)
GUI_TEST_CLASS_DECLARATION(test_0047)
GUI_TEST_CLASS_DECLARATION(test_0048)
GUI_TEST_CLASS_DECLARATION(test_0049)
GUI_TEST_CLASS_DECLARATION(test_0050)
GUI_TEST_CLASS_DECLARATION(test_0051)
GUI_TEST_CLASS_DECLARATION(test_0052)
GUI_TEST_CLASS_DECLARATION(test_0053)
GUI_TEST_CLASS_DECLARATION(test_0054)
GUI_TEST_CLASS_DECLARATION(test_0055)
GUI_TEST_CLASS_DECLARATION(test_0056)
GUI_TEST_CLASS_DECLARATION(test_0057)
GUI_TEST_CLASS_DECLARATION(test_0058)

// applicaation
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0060)
GUI_TEST_CLASS_DECLARATION(test_0061)
GUI_TEST_CLASS_DECLARATION(test_0062)
GUI_TEST_CLASS_DECLARATION(test_0063)

// msa
GUI_TEST_CLASS_DECLARATION(test_0064)
GUI_TEST_CLASS_DECLARATION(test_0065)
GUI_TEST_CLASS_DECLARATION(test_0066)
GUI_TEST_CLASS_DECLARATION(test_0067)

// seq
GUI_TEST_CLASS_DECLARATION(test_0068)
GUI_TEST_CLASS_DECLARATION(test_0069)
GUI_TEST_CLASS_DECLARATION(test_0070)
GUI_TEST_CLASS_DECLARATION(test_0071)

// annotations
GUI_TEST_CLASS_DECLARATION(test_0072)
GUI_TEST_CLASS_DECLARATION(test_0073)
GUI_TEST_CLASS_DECLARATION(test_0074)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_project

}  // namespace U2

#endif
